@@ -19,6 +19,7 @@
 #include <vector>
 #include <memory>
 #include <cstdint>
+#include <boost/property_tree/ptree_fwd.hpp>
 
 namespace RDKit {
 class ROMol;
@@ -106,6 +107,8 @@ class RDKIT_FINGERPRINTS_EXPORT FingerprintArguments {
    \return std::string information string
    */
   virtual std::string infoString() const = 0;
+  virtual void toJSON(boost::property_tree::ptree &pt) const;
+  virtual void fromJSON(const boost::property_tree::ptree &pt);
 
   /**
    \brief method that returns information string about common fingerprinting
@@ -201,6 +204,9 @@ class RDKIT_FINGERPRINTS_EXPORT AtomEnvironmentGenerator
    \return std::string information string
    */
   virtual std::string infoString() const = 0;
+  virtual void toJSON(boost::property_tree::ptree &) const {};
+  virtual void fromJSON(const boost::property_tree::ptree &) {};
+
   /*!
     \brief Returns the size of the fingerprint based on arguments
 
@@ -238,6 +244,8 @@ class RDKIT_FINGERPRINTS_EXPORT AtomInvariantsGenerator
    \return std::string information string
    */
   virtual std::string infoString() const = 0;
+  virtual void toJSON(boost::property_tree::ptree &) const {};
+  virtual void fromJSON(const boost::property_tree::ptree &) {};
 
   virtual ~AtomInvariantsGenerator() {}
   virtual AtomInvariantsGenerator *clone() const = 0;
@@ -268,6 +276,8 @@ class RDKIT_FINGERPRINTS_EXPORT BondInvariantsGenerator
  \return std::string information string
  */
   virtual std::string infoString() const = 0;
+  virtual void toJSON(boost::property_tree::ptree &) const {};
+  virtual void fromJSON(const boost::property_tree::ptree &) {};
 
   virtual ~BondInvariantsGenerator() {}
   virtual BondInvariantsGenerator *clone() const = 0;
@@ -410,7 +420,18 @@ class RDKIT_FINGERPRINTS_EXPORT FingerprintGenerator
   };
 
   std::string infoString() const;
+  void toJSON(boost::property_tree::ptree &pt) const;
+  void fromJSON(const boost::property_tree::ptree &pt);
 };
+//! generate JSON representation of a FingerprintGenerator
+template <typename OutputType>
+RDKIT_FINGERPRINTS_EXPORT std::string generatorToJSON(
+    const FingerprintGenerator<OutputType> &generator);
+
+//! create a FingerprintGenerator from its JSON representation
+///  note that the returned generator always uses std::uint64_t as OutputType.
+RDKIT_FINGERPRINTS_EXPORT std::unique_ptr<FingerprintGenerator<std::uint64_t>>
+generatorFromJSON(const std::string &jsonStr);
 
 template RDKIT_FINGERPRINTS_EXPORT ExplicitBitVect *
 FingerprintGenerator<std::uint32_t>::getFingerprint(
